#include <gnome.h>
#include <libgnomevfs/gnome-vfs.h>

int scan_directory(char * dir_name)
{
	GnomeVFSDirectoryHandle * handle;
	GnomeVFSFileInfo * file_info;
	GnomeVFSResult res;
	if ((res = gnome_vfs_directory_open(&handle, dir_name, GNOME_VFS_FILE_INFO_FOLLOW_LINKS)) 
		!= GNOME_VFS_OK) {
 		g_print("failed to open the directory: %s\n", 
			gnome_vfs_result_to_string(res));
		return res;
	}
	file_info = gnome_vfs_file_info_new();
	while ((res = gnome_vfs_directory_read_next(handle, file_info)) == GNOME_VFS_OK)
	{
		g_print("name: %s\n", file_info->name);
		g_print("type: ");
		switch(file_info->type)							
		{
			case GNOME_VFS_FILE_TYPE_REGULAR:
				g_print("file\n");
				break;
			case GNOME_VFS_FILE_TYPE_DIRECTORY:
				g_print("directory\n");
				break;
			case GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK:
				g_print("symbolic link\n");
				g_print("points to: %s\n", file_info->symlink_name);
				break;
			case GNOME_VFS_FILE_TYPE_FIFO:
				g_print("FIFO\n");
				break;
			case GNOME_VFS_FILE_TYPE_SOCKET:
				g_print("socket\n");
				break;
			case GNOME_VFS_FILE_TYPE_CHARACTER_DEVICE:
				g_print("char device\n");
				break;
			case GNOME_VFS_FILE_TYPE_BLOCK_DEVICE:
				g_print("block device\n");
				break;
			case GNOME_VFS_FILE_TYPE_UNKNOWN:
				g_print("unknown\n");
				break;
		}
		g_print("size: %lli\n\n", file_info->size);
		gnome_vfs_file_info_clear(file_info);
	}
	gnome_vfs_directory_close(handle);
	gnome_vfs_file_info_unref(file_info);
	if (res != GNOME_VFS_ERROR_EOF) {
		g_print("Error reading the directory: %s\n", 
			gnome_vfs_result_to_string(res));
		return res;
	}
    return 0;
}

int main(int argc, char * argv[])
{
	gnome_vfs_init();
	if (argc != 2)
		return 0;
	scan_directory(argv[1]);
	gnome_vfs_shutdown();
	return 0;
}
